@@ -17,26 +17,27 @@
 //!
 //! ## Multi Bars
 //!
-//! `Progress` does not implement [`Clone`] and must be wrapped in the usual
-//! [concurrent sharing types][arcmutex] before being passed between threads:
+//! To mutably access a [`Progress`] across threads it must be wrapped in the
+//! usual [concurrent sharing types][arcmutex]. With `rayon` specifically, only
+//! `Mutex` is necessary:
 //!
 //! ```
-//! use std::sync::{Arc, Mutex};
+//! use std::sync::Mutex;
 //! use linya::{Bar, Progress};
 //! use rayon::prelude::*;
 //!
-//! let progress = Arc::new(Mutex::new(Progress::new()));
+//! let progress = Mutex::new(Progress::new());
 //!
 //! // `into_par_iter()` is from `rayon`, and lets us parallelize some
 //! // operation over a collection "for free".
-//! (0..10).into_par_iter().for_each_with(progress, |p, n| {
-//!   let bar: Bar = p.lock().unwrap().bar(50, format!("Downloading {}", n));
+//! (0..10).into_par_iter().for_each(|n| {
+//!   let bar: Bar = progress.lock().unwrap().bar(50, format!("Downloading {}", n));
 //!
 //!   // ... Your logic ...
 //!
 //!   // Increment the bar and draw it immediately.
 //!   // This is likely called in some inner loop or other closure.
-//!   p.lock().unwrap().inc_and_draw(&bar, 10);
+//!   progress.lock().unwrap().inc_and_draw(&bar, 10);
 //! });
 //! ```
 //!
@@ -93,7 +94,7 @@
 //! [indicatif]: https://lib.rs/crates/indicatif
 
 #![warn(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/linya/0.2.0")]
+#![doc(html_root_url = "https://docs.rs/linya/0.2.1")]
 
 use std::io::{LineWriter, Stderr, Write};
 use terminal_size::{terminal_size, Height, Width};
@@ -117,6 +118,10 @@ impl Default for Progress {
     }
 }
 
+// You will notice in a number of the methods below that `Result` values from
+// calling `write!` are being ignored via a `let _ = ...` pattern, as opposed to
+// unwrapping. This avoids a rare panic that can occur under very specific shell
+// piping scenarios.
 impl Progress {
     /// Initialize a new progress bar coordinator.
     pub fn new() -> Progress {
@@ -147,15 +152,14 @@ impl Progress {
         let label: String = label.into();
 
         // An initial "empty" rendering of the new bar.
-        writeln!(
+        let _ = writeln!(
             &mut self.out,
             "{:<l$}      [{:->f$}]   0%",
             label,
             "",
             l = twidth - w - 8 - 5,
             f = w
-        )
-        .unwrap();
+        );
 
         let bar = SubBar {
             curr: 0,
@@ -196,7 +200,7 @@ impl Progress {
                 let diff = 100 * (b.curr - b.prev) / b.total;
 
                 if b.cancelled {
-                    write!(
+                    let _ = write!(
                         &mut self.out,
                         "\x1B[s\x1B[{}A\r{:<l$} {:3}{} [{:_>f$}] ???%\x1B[u\r",
                         pos,
@@ -206,13 +210,12 @@ impl Progress {
                         "",
                         l = term_width - w - 8 - 5,
                         f = w,
-                    )
-                    .unwrap();
+                    );
 
                     // Very important, or the output won't appear fluid.
-                    self.out.flush().unwrap();
+                    let _ = self.out.flush();
                 } else if b.curr >= b.total {
-                    write!(
+                    let _ = write!(
                         &mut self.out,
                         "\x1B[s\x1B[{}A\r{:<l$} {:3}{} [{:#>f$}] 100%\x1B[u\r",
                         pos,
@@ -222,15 +225,14 @@ impl Progress {
                         "",
                         l = term_width - w - 8 - 5,
                         f = w,
-                    )
-                    .unwrap();
-                    self.out.flush().unwrap();
+                    );
+                    let _ = self.out.flush();
                 } else if diff >= 1 {
                     b.prev = b.curr;
                     let f = (w * b.curr / b.total).min(w - 1);
                     let e = (w - 1) - f;
 
-                    write!(
+                    let _ = write!(
                         &mut self.out,
                         "\x1B[s\x1B[{}A\r{:<l$} {:3}{} [{:#>f$}>{:->e$}] {:3}%\x1B[u\r",
                         pos,
@@ -243,9 +245,8 @@ impl Progress {
                         l = term_width - w - 8 - 5,
                         f = f,
                         e = e
-                    )
-                    .unwrap();
-                    self.out.flush().unwrap();
+                    );
+                    let _ = self.out.flush();
                 }
             }
         }
